
#Convention for strings representing files
# #_file has the extention
#           #name does not have the extension


# set friction value for zone
fric_first=33
fric_second=0.3

# fwojhrt
import time

import project_friction

from anuga.pyvolution.pmesh2domain import pmesh_to_domain_instance 
from caching import cache
from anuga.pyvolution.shallow_water import Domain, Reflective_boundary,\
     File_boundary, Dirichlet_boundary, Time_boundary, Transmissive_boundary,\
     Set_region
from anuga.pyvolution.least_squares import fit_to_mesh_file, DEFAULT_ALPHA 


from two_friction_block import create_mesh
#from building_generator import create_mesh

from anuga.pmesh.mesh import importMeshFromFile

meshname = project_friction.meshname
outputname = project_friction.outputname

t0 = time.time()

#meshname, triagle_count =create_mesh(100,mesh_file=meshname,triangles_in_name=True)

meshname, triagle_count = cache(create_mesh,(100),
                                {'mesh_file':meshname,
                                 'triangles_in_name':True}
                                ,dependencies = ['two_friction_block.py']
                                #,evaluate = True      
                                )
#meshname = 'build.tsh'
#outputname = outputname[:-4] + '_' + str(triagle_count) + outputname[-4:]

print 'Initialising the mesh took %.2f seconds' %(time.time()-t0)  


#meshname = importMeshFromFile('build.tsh')

#Setup domain
domain = cache(pmesh_to_domain_instance, (meshname, Domain),
               dependencies = [meshname]                    
               ,verbose = False
               )               


domain.set_name(project_friction.basename + 'Dbl_%d_%d' %(fric_first, fric_second))
domain.set_datadir(project_friction.outputdir)
domain.store = True
domain.quantities_to_be_stored = ['stage','xmomentum','ymomentum']

print 'Number of triangles = ', len(domain)
print 'The extent is ', domain.get_extent()

#Setup Initial Conditions
domain.set_quantity('friction', 0.01)
domain.set_quantity('stage', 0)
domain.set_region(Set_region('first_block', 'friction', fric_first)) #, location='unique vertices'))
domain.set_region(Set_region('second_block', 'friction', fric_second)) #, location='unique vertices'))

#Setup Boundary Conditions
print domain.get_boundary_tags()

domain.starttime = 0  #Obtained from MOST

Br = Reflective_boundary(domain)
Bt = Transmissive_boundary(domain)
Bdw = Dirichlet_boundary([20,0,0])
Bdb = Dirichlet_boundary([0,0,0])
Bw = Time_boundary(domain=domain,
                   f=lambda t: [(60<t<660)*4, 0, 0])

domain.set_boundary( {'wall': Br,'wave': Bdw, 'back': Bdb, 'exterior':Bdw} ) 

#Evolve
t0 = time.time()

for t in domain.evolve(yieldstep = 10, finaltime = 1000):
    domain.write_time()      

print 'That took %.2f seconds' %(time.time()-t0)
